@@ -176,25 +176,25 @@ intercept.perc <- sDIFintercept <- species <-  NULL
                                                   colour="black"))
 
         ### Plotting:
-        if (param == "estimate" & graphs == "all")
+        if (param == "estimate" && graphs == "all")
             suppressMessages(return(multiplot(s1, s3, s2, s4, cols = 2)))
-        if (param == "estimate" & graphs == 1)
+        if (param == "estimate" && graphs == 1)
             suppressMessages(return(s1))
-        if (param == "estimate" & graphs == 2)
+        if (param == "estimate" && graphs == 2)
             suppressMessages(return(s2))
-        if (param == "estimate" & graphs == 3)
+        if (param == "estimate" && graphs == 3)
             suppressMessages(return(s3))
-        if (param == "estimate" & graphs == 4)
+        if (param == "estimate" && graphs == 4)
             suppressMessages(return(s4))
-        if (param == "intercept" & graphs == "all")
+        if (param == "intercept" && graphs == "all")
             suppressMessages(return(multiplot(i1, i3, i2, i4, cols = 2)))
-        if (param == "intercept" & graphs == 1)
+        if (param == "intercept" && graphs == 1)
             suppressMessages(return(i1))
-        if (param == "intercept" & graphs == 2)
+        if (param == "intercept" && graphs == 2)
             suppressMessages(return(i2))
-        if (param == "intercept" & graphs == 3)
+        if (param == "intercept" && graphs == 3)
             suppressMessages(return(i3))
-        if (param == "intercept" & graphs == 4)
+        if (param == "intercept" && graphs == 4)
             suppressMessages(return(i4))
 
         ### Warnings
